/*

  This is a part of Layercut.dll source code.
  
  Copyright (C) 2001-2002 Sylvain Rouquette
  rouque_s@epita.fr
  http://www.epita.fr:8000/~rouque_s

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __LAYERCUT_H_
#define __LAYERCUT_H_

#include <vector>
#include <string>
#include "../lsapi/common.h"
#include "../lsapi/lswinbase.h"

using namespace std;

extern BYTE alpha_threshold;

class CImageStorage;
class CAnimation;

class CImage
{
public:
	CImage() {};
	CImage(HBITMAP bmp, CAnimation *anim);
	~CImage()
	{
		if (image)
			DeleteObject(image);
		if (region)
			DeleteObject(region);
	};

  HBITMAP	image;
  HRGN		region;
};

class CAnimation
{
public:
	CAnimation() { reset(); };
	~CAnimation();
	int init(string &n, CAnimation *img);
	void setPos(int &p, bool goon = false);
	void computeImage(HBITMAP bmp, CAnimation *image);
	void reset()
	{
		name.erase();
		width = height = 0;
		is_animated = has_alpha = is_opaque = loop = priority = false;
		speed = 100;
		min = max = max_size = 0;
	}

	string						name;
	vector<CImage *>	anim;
	int			width, height;
	int			pos, speed;
	int			min, max, max_size;
	bool		has_alpha, is_opaque, loop;
	bool		is_animated, finish, priority;
	CImage	*current;
};

class CImageStorage
{
public:
	CImageStorage();
	~CImageStorage();
	void loadAnimation();
	void bubble(CAnimation *anim, int deb, int fin);
	void qsort(int deb, int fin);
	CAnimation *loadImage(string &str, CAnimation *img);
	CAnimation *getImage(string &str, int pos);

	vector<CAnimation *>	list;
};

#endif